<?
// po poprawkach
namespace admin\controls;

class Restriction
{  
  public function getContentEmails()
	{
		$rw = \System::formGet( 'rw' );

		if ( $rw == 'edit' )
			return \admin\view\Restriction::editBannedEmail( \System::formGet( 'id' ) );
    
		if ( $rw == 'add' )
			return \admin\view\Restriction::editBannedEmail();
    
    if ( $rw == 'del' )
      \admin\factory\Restriction::deleteBannedEmail( \System::formGet( 'id' ) );
    
    return \admin\view\Restriction::showBannedEmails();
	}
  
  public function getContentLogins()
  {
    $rw = \System::formGet( 'rw' );

    if ( $rw == 'edit' )
      return \admin\view\Restriction::editBannedLogin( \System::formGet( 'id' ) );
    
    if ( $rw == 'add' )
      return \admin\view\Restriction::editBannedLogin();
    
    if ( $rw == 'del' )
      \admin\factory\Restriction::deleteBannedLogin( \System::formGet( 'id' ) );
    
    return \admin\view\Restriction::showBannedLogins();
  }
}
?>